<?php

/**
 * A simple interface description for use in storage classes.
 *
 * PHP version 5.3
 *
 * LICENSE:
 *
 * Copyright (c) 2009-2017, Günther Mair <info@inet-services.it>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1) Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2) Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 3) Neither the name of Günther Mair nor the names of its contributors may be
 *    used to endorse or promote products derived from this software without
 *    specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * @category    Net
 * @package     Net_EPP_WebInterface_StorageDB
 * @author      Günther Mair <info@inet-services.it>
 * @license     http://opensource.org/licenses/bsd-license.php New BSD License
 *
 * $Id$
 */
interface Net_EPP_WebInterface_StorageInterface
{
  // contact operations
  public function listContacts($userid = 1, $activeOnly = TRUE);
  public function deleteContact($contact, $userid = 1);
  public function restoreContact($contact, $userid = 1);

  // domain operations
  public function listDomains($userid = 1, $handle = null, $activeOnly = TRUE, $age = 0);
  public function deleteDomain($domain, $userid = 1);
  public function restoreDomain($domain, $userid = 1);
  public function invoiceableDomains();
  public function renewDomains();

  // accounting operations
  public function doAccount($operation, $billingID, $object, $date = NULL);
  public function accountableServices();
  public function closeAccountableServices($records);
  public function creditForecast($days);

  // transfer operations
  public function storeTransfer($domain, $registrant, $techc, $dns, $userid = 1);
  public function lookupTransfer($domain, $userid = 1);
  public function listTransfers($registrant = "", $userid = 1);
  public function deleteTransfer($domain, $userid = 1);

  // reminder operations
  public function setReminder($domain, $date, $notice, $email, $userid = 1);
  public function getReminder($domain = null, $userid = 1, $doRemind = false);
  public function archiveReminder($id, $userid = 1);

  // local account operations
  public function changePassword($newPassword, $userid);

  // generic operations
  public function exportDomains($userid = 1);
  public function autocompleteDomain($search, $limit, $userid = 1);
}
