#!/usr/bin/php
<?php

// read/verify configuration file
$root = realpath(dirname(__FILE__)."/..");
$cfg = @simplexml_load_file($root."/config.xml");
if ( $cfg === FALSE )
  die($root."/config.xml is not readable\n");
if ( ! file_exists($root."/docs/dbupdate") )
  die($root."/docs/dbupdate/ does not exist\n");

// create DB connection
try {
  $db = new PDO("{$cfg->db->dbtype}:host={$cfg->db->dbhost};dbname={$cfg->db->dbname};charset=utf8", $cfg->db->dbuser, $cfg->db->dbpwd);
  $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
  $db->setAttribute(PDO::ATTR_EMULATE_PREPARES, FALSE);
} catch (PDOException $e) {
  $err = $e->getMessage();
  echo "Unable to connect to database '{$cfg->db->dbname}' on '{$cfg->db->dbhost}' with user '{$cfg->db->dbuser}': ".rtrim($err)."\n";
}

// read update scripts
$scripts = array();
$d = dir($root."/docs/dbupdate");
while ($entry = $d->read()) {
  if (substr($entry, -4) != ".sql") continue;
  $scripts[] = $entry;
}
$d->close();

// sort scripts
sort($scripts);

// run scripts
foreach ($scripts as $entry) {
  // execute the script
  echo "- running [".$entry."] ...";
  try {
    $stmt = $db->prepare(file_get_contents($root."/docs/dbupdate/".$entry));
    $stmt->execute();
    if ($stmt->execute()) {
      echo " OK.\n";
    } else {
      $errorInfo = $stmt->errorInfo();
      echo " FAILED [{$errorInfo[1]}: unable to list contacts: {$errorInfo[2]}].\n";
    }
  } catch (PDOException $e) {
    $errorInfo = rtrim($e->getMessage());
    echo " exception caught [{$errorInfo}].\n";
  }
}
